{% extends "wedding/blocks/base.html" %}

{% block title %}
{{ title }}
{% endblock %}

{% block content %}

<div id="login" class="container-fluid text-center page-container">
    <h1 class="page-header">Password Reset Successfully Requested</h1>

    <p>We've emailed you instructions for setting your password, if an account exists with the email you entered. You should receive them shortly.</p>

    <p>If you don't receive an email, please make sure you've entered the address you registered with, and check your spam folder.</p>

</div>

{% endblock %}
