{% extends "wedding/blocks/base.html" %}

{% block title %}
{{ title }}
{% endblock %}

{% block content %}

<div id="login" class="container-fluid text-center page-container">
    <h1 class="page-header">Password Reset</h1>

        <p>Forgotten your password? Enter your email address below, and we'll email instructions for setting a new one.</p>

        <form method="post">{% csrf_token %}
        <fieldset class="module aligned">
            <div class="form-row field-email">
                {{ form.email.errors }}
                <label for="id_email">Email address:</label>
                {{ form.email }}
            </div>
            <input type="submit" class="login-button" value="Reset my password" />
        </fieldset>
        </form>
</div>

{% endblock %}
