{% extends "wedding/blocks/base.html" %}

{% block title %}
{{ title }}
{% endblock %}

{% block content %}

<div id="login" class="container-fluid text-center page-container">
    <h1 class="page-header">Password Reset Complete</h1>

    <p>Your password has been set.  You may go ahead and log in now.</p>

    <p><a href="{% url 'login' %}?next={% url 'index' %}">Log in</a></p>
</div>

{% endblock %}
