{% extends "easy_maps/map.html" %}

{% block html %}
<div id="map-canvas-{{ map.pk }}" class="easy-map-googlemap wedding-map">
  {% block noscript %}{{ block.super }}{% endblock %}
  {% if not map.computed_address %}<!-- geocoding error -->{% endif %}
</div>
{% endblock %}
